=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2005-10-17 08:00:50 +0000
+++ bzrlib/errors.py	2005-10-17 09:36:43 +0000
@@ -54,8 +54,12 @@
 # python exceptions?   A list of values with no names seems less useful 
 # to me.
 
-# TODO: perhaps convert the exception to a string at the moment it's 
-# constructed to make sure it will succeed
+# TODO: Perhaps convert the exception to a string at the moment it's 
+# constructed to make sure it will succeed.  But that says nothing about
+# exceptions that are never raised.
+
+# TODO: Convert all the other error classes here to BzrNewError, and eliminate
+# the old one.
 
 
 class BzrError(StandardError):
@@ -94,17 +98,26 @@
                 % (self.__class__.__name__, str(e))
 
 
-class BzrCheckError(BzrError):
-    pass
-
-
-class InvalidRevisionNumber(BzrError):
-    def __str__(self):
-        return 'invalid revision number: %r' % self.args[0]
-
-
-class InvalidRevisionId(BzrError):
-    pass
+class BzrCheckError(BzrNewError):
+    """Internal check failed: %(message)s"""
+    def __init__(self, message):
+        self.message = message
+
+
+class InvalidEntryName(BzrNewError):
+    """Invalid entry name: %(name)s"""
+    def __init__(self, name):
+        self.name = name
+
+
+class InvalidRevisionNumber(BzrNewError):
+    """Invalid revision number %(revno)d"""
+    def __init__(self, revno):
+        self.revno = revno
+
+
+class InvalidRevisionId(BzrNewError):
+    """Invalid revision-id"""
 
 
 class BzrCommandError(BzrError):
@@ -143,16 +156,10 @@
 
 
 class LockError(Exception):
-    """All exceptions from the lock/unlock functions should be from
-    this exception class.  They will be translated as necessary. The
-    original exception is available as e.original_error
-    """
-    def __init__(self, e=None):
-        self.original_error = e
-        if e:
-            Exception.__init__(self, e)
-        else:
-            Exception.__init__(self)
+    """Lock error"""
+    # All exceptions from the lock/unlock functions should be from
+    # this exception class.  They will be translated as necessary. The
+    # original exception is available as e.original_error
 
 
 class CommitNotPossible(LockError):
@@ -167,7 +174,7 @@
     """A write attempt was made in a read only transaction."""
 
 
-class PointlessCommit(Exception):
+class PointlessCommit(BzrNewError):
     """Commit failed because nothing was changed."""
 
 

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2005-10-16 05:15:58 +0000
+++ bzrlib/inventory.py	2005-10-17 09:36:43 +0000
@@ -31,12 +31,11 @@
 import types
 
 import bzrlib
-from bzrlib.errors import BzrError, BzrCheckError
-
 from bzrlib.osutils import (pumpfile, quotefn, splitpath, joinpath,
                             appendpath, sha_strings)
 from bzrlib.trace import mutter
-from bzrlib.errors import NotVersionedError
+from bzrlib.errors import (NotVersionedError, InvalidEntryName,
+                           BzrError, BzrCheckError)
 
 
 class InventoryEntry(object):
@@ -229,12 +228,11 @@
         '123'
         >>> e = InventoryFile('123', 'src/hello.c', ROOT_ID)
         Traceback (most recent call last):
-        BzrCheckError: InventoryEntry name 'src/hello.c' is invalid
+        InvalidEntryName: Invalid entry name: src/hello.c
         """
         assert isinstance(name, basestring), name
         if '/' in name or '\\' in name:
-            raise BzrCheckError('InventoryEntry name %r is invalid' % name)
-        
+            raise InvalidEntryName(name=name)
         self.executable = False
         self.revision = None
         self.text_sha1 = None

